<?php

namespace Tests\Feature;

use App\Models\Channel;
use App\Models\Comment;
use App\Models\Group;
use App\Models\Like;
use App\Models\Message;
use App\Models\Post;
use App\Models\Profile;
use App\Models\User;
use Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ModelRelationsTest extends TestCase
{
    use RefreshDatabase;

    public function test_user_and_profile()
    {
        $user = User::create(['name' => 'Test User', 'email' => 'test@example.com', 'password' => 'password']);
        $profile = $user->profile()->create(['bio' => 'This is a bio']);

        $this->assertInstanceOf(Profile::class, $profile);
        $this->assertEquals($profile->id, $user->profile->id);
        $this->assertEquals($user->id, $profile->user->id);
    }

    public function test_post_has_many_comments()
    {
        $user = User::create(['name' => 'Test User', 'email' => 'test@example.com', 'password' => 'password']);
        $channel = Channel::create(['name' => 'Test Channel']);
        $post = Post::create(['content' => 'Test post', 'user_id' => 1, 'channel_id' => 1]);
        $comment1 = $post->comments()->create(['content' => 'First comment', 'user_id' => 1]);
        $comment2 = $post->comments()->create(['content' => 'Second comment', 'user_id' => 1]);

        $this->assertCount(2, $post->comments);
        $this->assertEquals($comment1->id, $post->comments[0]->id);
        $this->assertEquals($comment2->id, $post->comments[1]->id);
    }
}